@@ -227,16 +227,19 @@ class Authing():
             raise Exception('请提供密码：password')
 
         loginQuery = """
-            mutation login($unionid: String, $email: String, $password: String, $lastIP: String, $registerInClient: String!, $verifyCode: String) {
-                login(unionid: $unionid, email: $email, password: $password, lastIP: $lastIP, registerInClient: $registerInClient, verifyCode: $verifyCode) {
+            mutation login($unionid: String, $email: String, $username: String, $password: String, $lastIP: String, $registerInClient: String!, $verifyCode: String, $browser: String, $openid: String, $MFACode: String) {
+                login(unionid: $unionid, email: $email, username: $username, password: $password, lastIP: $lastIP, registerInClient: $registerInClient, verifyCode: $verifyCode, browser: $browser, openid: $openid, MFACode: $MFACode) {
                     _id
                     email
                     emailVerified
+                    unionid
+                    openid
+                    oauth
+                    registerMethod
                     username
                     nickname
                     company
                     photo
-                    browser
                     token
                     tokenExpiredAt
                     loginsCount
@@ -245,8 +248,9 @@ class Authing():
                     signedUp
                     blocked
                     isDeleted
+                    metadata
+                    }
                 }
-            }
         """
 
         _password = self.encrypt(password)
